package
Version:
v0.1.0
Opens a new window with list of versions in this module.
Published: Dec 14, 2019
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func OKData(data interface{}) []byte
OKData 响应 http 成功
type ResResult struct {
Ok bool
Msg string
ResultData interface{}
}
ResResult 用来传递 http 响应的
Source Files
¶
Click to show internal directories.
Click to hide internal directories.